@@ -1,10 +1,12 @@
 import os
 
+from vellum.api_resources.types import GenerateRequest
 from vellum.api_resources import Generate
 
 api_key = os.environ.get("VELLUM_API_KEY")
 
 __all__ = [
     "Generate",
+    "GenerateRequest",
     "api_key",
 ]
